package com.ruoyi.szxc.mapper;

import com.ruoyi.szxc.domain.SzxcJmHouse;

import java.util.List;

/**
 * 居民房屋关联Mapper接口
 *
 * @author hs
 * @date 2024-03-30
 */
public interface SzxcJmHouseMapper
{
    /**
     * 查询居民房屋关联
     *
     * @param id 居民房屋关联主键
     * @return 居民房屋关联
     */
    public SzxcJmHouse selectSzxcJmHouseById(Long id);

    /**
     * 查询居民房屋关联列表
     *
     * @param szxcJmHouse 居民房屋关联
     * @return 居民房屋关联集合
     */
    public List<SzxcJmHouse> selectSzxcJmHouseList(SzxcJmHouse szxcJmHouse);

    /**
     * 新增居民房屋关联
     *
     * @param szxcJmHouse 居民房屋关联
     * @return 结果
     */
    public int insertSzxcJmHouse(SzxcJmHouse szxcJmHouse);

    /**
     * 修改居民房屋关联
     *
     * @param szxcJmHouse 居民房屋关联
     * @return 结果
     */
    public int updateSzxcJmHouse(SzxcJmHouse szxcJmHouse);

    /**
     * 删除居民房屋关联
     *
     * @param id 居民房屋关联主键
     * @return 结果
     */
    public int deleteSzxcJmHouseById(Long id);

    /**
     * 批量删除居民房屋关联
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcJmHouseByIds(Long[] ids);
}
